# Contributing to Baseguide

:tada: First off, thanks for taking the time to contribute! :tada:

## How Can I Contribute?

### Reporting Bugs

#### How Do I Submit A (Good) Bug Report?

Bugs are tracked as [GitHub issues](https://guides.github.com/features/issues/).

Before creating bug reports, please search the [issues](https://github.com/slavanga/baseguide/issues?utf8=%E2%9C%93&q=is%3Aissue) to see if the problem has already been reported.

Explain the problem and include additional details to help maintainers reproduce the problem:

* **Use a clear and descriptive title** for the issue to identify the problem.
* **Describe the exact steps which reproduce the problem** in as many details as possible. When listing steps, **don't just say what you did, but explain how you did it**.
* **Provide specific examples to demonstrate the steps**. Include links to files or GitHub projects, or copy/pasteable snippets, which you use in those examples. If you're providing snippets in the issue, use [Markdown code blocks](https://help.github.com/articles/markdown-basics/#multiple-lines).
* **Describe the behavior you observed after following the steps** and point out what exactly is the problem with that behavior.
* **Explain which behavior you expected to see instead and why.**
* **Include screenshots and animated GIFs** which show you following the described steps and clearly demonstrate the problem. You can use [this tool](https://www.cockos.com/licecap/) to record GIFs on macOS and Windows, and [this tool](https://github.com/colinkeenan/silentcast) or [this tool](https://github.com/GNOME/byzanz) on Linux.

Include details about your configuration and environment:

* Which version of Baseguide are you using?
* Are you using custom settings?

### Pull Requests

Before submitting pull requests for enhancements you should open an issue to discuss the changes.

## Local development

Baseguide can be developed locally. For instructions on how to do this, see the [development section](https://github.com/slavanga/baseguide#development) in the readme.

## Styleguides

### Git Commit Messages

* Use the present tense ("Add feature" not "Added feature")
* Use the imperative mood ("Move cursor to..." not "Moves cursor to...")
* Limit the first line to 72 characters or less
* Reference issues and pull requests liberally after the first line

### Code Linting

Please run ```gulp lint``` before every commit to format your code.
